pub struct Create {
Show 18 fields pub sender: Pubkey, pub sender_tokens: Pubkey, pub recipient: Pubkey, pub metadata: Pubkey, pub escrow_tokens: Pubkey, pub recipient_tokens: Pubkey, pub streamflow_treasury: Pubkey, pub streamflow_treasury_tokens: Pubkey, pub withdrawor: Pubkey, pub partner: Pubkey, pub partner_tokens: Pubkey, pub mint: Pubkey, pub fee_oracle: Pubkey, pub rent: Pubkey, pub streamflow_program: Pubkey, pub token_program: Pubkey, pub associated_token_program: Pubkey, pub system_program: Pubkey,
}
Generated client accounts for Create.

Fields

sender: Pubkey

Wallet of the contract creator.

sender_tokens: Pubkey

Associated token account address of sender.

recipient: Pubkey

Wallet address of the recipient.

metadata: Pubkey

The account holding the contract parameters. Expects empty (non-initialized) account.

escrow_tokens: Pubkey

The escrow account holding the funds. Expects empty (non-initialized) account.

recipient_tokens: Pubkey

Associated token account address of recipient.

streamflow_treasury: Pubkey

Streamflow treasury account.

streamflow_treasury_tokens: Pubkey

Associated token account address of streamflow_treasury.

withdrawor: Pubkey

Delegate account for automatically withdrawing contracts.

partner: Pubkey

Partner treasury account. If no partner fees are expected on behalf of the program integrating with streamflow, streamflow_treasury can be passed in here.

partner_tokens: Pubkey

Associated token account address of partner. If no partner fees are expected on behalf of the program integrating with streamflow, streamflow_treasury_tokens can be passed in here.

mint: Pubkey

The SPL token mint account.

fee_oracle: Pubkey

Internal program that handles fees for specified partners. If no partner fees are expected on behalf of the program integrating with streamflow, streamflow_treasury can be passed in here.

rent: Pubkey

The Rent Sysvar account.

streamflow_program: Pubkey

Streamflow protocol (alias timelock) program account.

token_program: Pubkey

The SPL program needed in case an associated account for the new recipient is being created.

associated_token_program: Pubkey

The Associated Token program needed in case associated account for the new recipient is being created.

system_program: Pubkey

The Solana system program needed for account creation.