pub struct Transfer {
    pub authority: Pubkey,
    pub new_recipient: Pubkey,
    pub new_recipient_tokens: Pubkey,
    pub metadata: Pubkey,
    pub mint: Pubkey,
    pub rent: Pubkey,
    pub token_program: Pubkey,
    pub associated_token_program: Pubkey,
    pub system_program: Pubkey,
}
Generated client accounts for Transfer.

Fields

authority: Pubkey

Wallet that initiates contract transfer.

new_recipient: Pubkey

Wallet address of the new contract recipient

new_recipient_tokens: Pubkey

Wallet address of the new contract recipient’s token account

metadata: Pubkey

The account holding the contract parameters. Expects initialized account.

mint: Pubkey

The SPL token mint account.

rent: Pubkey

The Rent Sysvar account.

token_program: Pubkey

The SPL program needed in case an associated account for the new recipient is being created.

associated_token_program: Pubkey

The Associated Token program needed in case associated account for the new recipient is being created.

system_program: Pubkey

The Solana system program needed for account creation.