pub struct Withdraw {
    pub authority: Pubkey,
    pub recipient: Pubkey,
    pub recipient_tokens: Pubkey,
    pub metadata: Pubkey,
    pub escrow_tokens: Pubkey,
    pub streamflow_treasury: Pubkey,
    pub streamflow_treasury_tokens: Pubkey,
    pub partner: Pubkey,
    pub partner_tokens: Pubkey,
    pub mint: Pubkey,
    pub token_program: Pubkey,
}
Generated client accounts for Withdraw.

Fields

authority: Pubkey

Wallet of the contract withdrawor.

recipient: Pubkey

Wallet address of the recipient.

recipient_tokens: Pubkey

Associated token account address of recipient.

metadata: Pubkey

The account holding the contract parameters. Expects initialized account.

escrow_tokens: Pubkey

The escrow account holding the funds. Expects initialized account.

streamflow_treasury: Pubkey

Streamflow treasury account.

streamflow_treasury_tokens: Pubkey

Associated token account address of streamflow_treasury.

partner: Pubkey

Partner treasury account. If no partner fees are expected on behalf of the program integrating with streamflow, streamflow_treasury can be passed in here. Must match partner account in contract metadata.

partner_tokens: Pubkey

Associated token account address of partner. If no partner fees are expected on behalf of the program integrating with streamflow, streamflow_treasury_tokens can be passed in here. Must match partner token account in contract metadata.

mint: Pubkey

The SPL token mint account.

token_program: Pubkey

The SPL program needed in case an associated account for the new recipient is being created.