pub struct CreateUncheckedV2 {Show 19 fields
pub start_time: u64,
pub net_amount_deposited: u64,
pub period: u64,
pub amount_per_period: u64,
pub cliff: u64,
pub cliff_amount: u64,
pub cancelable_by_sender: bool,
pub cancelable_by_recipient: bool,
pub automatic_withdrawal: bool,
pub transferable_by_sender: bool,
pub transferable_by_recipient: bool,
pub can_topup: bool,
pub stream_name: [u8; 64],
pub withdraw_frequency: u64,
pub recipient: Pubkey,
pub partner: Pubkey,
pub pausable: bool,
pub can_update_rate: bool,
pub nonce: u32,
}Expand description
Instruction.
Fields
start_time: u64net_amount_deposited: u64period: u64amount_per_period: u64cliff: u64cliff_amount: u64cancelable_by_sender: boolcancelable_by_recipient: boolautomatic_withdrawal: booltransferable_by_sender: booltransferable_by_recipient: boolcan_topup: boolstream_name: [u8; 64]withdraw_frequency: u64recipient: Pubkeypartner: Pubkeypausable: boolcan_update_rate: boolnonce: u32Trait Implementations
Sourceimpl BorshDeserialize for CreateUncheckedV2where
u64: BorshDeserialize,
bool: BorshDeserialize,
[u8; 64]: BorshDeserialize,
Pubkey: BorshDeserialize,
u32: BorshDeserialize,
impl BorshDeserialize for CreateUncheckedV2where
u64: BorshDeserialize,
bool: BorshDeserialize,
[u8; 64]: BorshDeserialize,
Pubkey: BorshDeserialize,
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateUncheckedV2where
u64: BorshSerialize,
bool: BorshSerialize,
[u8; 64]: BorshSerialize,
Pubkey: BorshSerialize,
u32: BorshSerialize,
impl BorshSerialize for CreateUncheckedV2where
u64: BorshSerialize,
bool: BorshSerialize,
[u8; 64]: BorshSerialize,
Pubkey: BorshSerialize,
u32: BorshSerialize,
Sourceimpl Discriminator for CreateUncheckedV2
impl Discriminator for CreateUncheckedV2
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateUncheckedV2
impl InstructionData for CreateUncheckedV2