Struct streamflow_sdk::accounts::Create
source · [−]pub struct Create {Show 18 fields
pub sender: Pubkey,
pub sender_tokens: Pubkey,
pub recipient: Pubkey,
pub metadata: Pubkey,
pub escrow_tokens: Pubkey,
pub recipient_tokens: Pubkey,
pub streamflow_treasury: Pubkey,
pub streamflow_treasury_tokens: Pubkey,
pub withdrawor: Pubkey,
pub partner: Pubkey,
pub partner_tokens: Pubkey,
pub mint: Pubkey,
pub fee_oracle: Pubkey,
pub rent: Pubkey,
pub streamflow_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for Create.
Fields
sender: PubkeyWallet of the contract creator.
sender_tokens: PubkeyAssociated token account address of sender.
recipient: PubkeyWallet address of the recipient.
metadata: PubkeyThe account holding the contract parameters. Expects empty (non-initialized) account.
escrow_tokens: PubkeyThe escrow account holding the funds. Expects empty (non-initialized) account.
recipient_tokens: PubkeyAssociated token account address of recipient.
streamflow_treasury: PubkeyStreamflow treasury account.
streamflow_treasury_tokens: PubkeyAssociated token account address of streamflow_treasury.
withdrawor: PubkeyDelegate account for automatically withdrawing contracts.
partner: PubkeyPartner treasury account. If no partner fees are expected on behalf of the program
integrating with streamflow, streamflow_treasury can be passed in here.
partner_tokens: PubkeyAssociated token account address of partner. If no partner fees are expected on behalf of the
program integrating with streamflow, streamflow_treasury_tokens can be passed in here.
mint: PubkeyThe SPL token mint account.
fee_oracle: PubkeyInternal program that handles fees for specified partners. If no partner fees are expected
on behalf of the program integrating with streamflow, streamflow_treasury can be passed
in here.
rent: PubkeyThe Rent Sysvar account.
streamflow_program: PubkeyStreamflow protocol (alias timelock) program account.
token_program: PubkeyThe SPL program needed in case an associated account for the new recipient is being created.
associated_token_program: PubkeyThe Associated Token program needed in case associated account for the new recipient is being created.
system_program: PubkeyThe Solana system program needed for account creation.