Struct streamflow_sdk::accounts::Withdraw
source · [−]pub struct Withdraw {
pub authority: Pubkey,
pub recipient: Pubkey,
pub recipient_tokens: Pubkey,
pub metadata: Pubkey,
pub escrow_tokens: Pubkey,
pub streamflow_treasury: Pubkey,
pub streamflow_treasury_tokens: Pubkey,
pub partner: Pubkey,
pub partner_tokens: Pubkey,
pub mint: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for Withdraw.
Fields
Wallet of the contract withdrawor.
recipient: PubkeyWallet address of the recipient.
recipient_tokens: PubkeyAssociated token account address of recipient.
metadata: PubkeyThe account holding the contract parameters. Expects initialized account.
escrow_tokens: PubkeyThe escrow account holding the funds. Expects initialized account.
streamflow_treasury: PubkeyStreamflow treasury account.
streamflow_treasury_tokens: PubkeyAssociated token account address of streamflow_treasury.
partner: PubkeyPartner treasury account. If no partner fees are expected on behalf of the program
integrating with streamflow, streamflow_treasury can be passed in here.
Must match partner account in contract metadata.
partner_tokens: PubkeyAssociated token account address of partner. If no partner fees are expected on behalf of the
program integrating with streamflow, streamflow_treasury_tokens can be passed in here.
Must match partner token account in contract metadata.
mint: PubkeyThe SPL token mint account.
token_program: PubkeyThe SPL program needed in case an associated account for the new recipient is being created.